@@ -26,7 +26,7 @@ from PyQt4.QtCore import pyqtSignature
 from Ui_help import Ui_HelpWindow
 from PyQt4.QtCore import QUrl
 from os import path
-from PyQt4.QtWebKit import *
+from PyQt4 import QtWebKit
 
 class HelpWindow(QMainWindow, Ui_HelpWindow):
     """
